==> haskell-store-core-0.4.4.7-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store-core
version:              0.4.4.7
visibility:           public
id:                   store-core-0.4.4.7-9DK5CSp988cKuvZaJb9ww8
key:                  store-core-0.4.4.7-9DK5CSp988cKuvZaJb9ww8
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  b6dcdc0189facbc574e638ebcf4407ee
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store-core
hs-libraries:         HSstore-core-0.4.4.7-9DK5CSp988cKuvZaJb9ww8
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-prim-0.9.1
    primitive-0.9.1.0-ICFc9Oc8RCqLS4oNEzcX43 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-core-0.4.4.7-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store-core
version:              0.4.4.7
visibility:           public
id:                   store-core-0.4.4.7-7LUpetcC2SZ16b6CMqIz5I
key:                  store-core-0.4.4.7-7LUpetcC2SZ16b6CMqIz5I
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  9f2e43e9ef6701d0fd3d8f3ed1cebea8
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/store-core-0.4.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store-core
hs-libraries:         HSstore-core-0.4.4.7-7LUpetcC2SZ16b6CMqIz5I
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-prim-0.9.1
    primitive-0.9.1.0-2rF1KRuV9tjItame9gIzcT text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
